@@ -248,28 +248,28 @@ c=======================================================================
 c+++++Data
       integer maxni,mpar,nrec,nsubject,nfixed,p,q,subject(nrec)
       integer datastr(nsubject,maxni+1),y(nrec)
-      real*8 roffset(nrec),x(nrec,p),z(nrec,q)
+      double precision roffset(nrec),x(nrec,p),z(nrec,q)
 
 c+++++Prior 
       integer nu0,murand,sigmarand
-      real*8 aa0,ab0,a0b0(2),b0(p),prec(p,p),psiinv(q,q)
-      real*8 sb(p),smu(q)
-      real*8 tinv(q,q)      
+      double precision aa0,ab0,a0b0(2),b0(p),prec(p,p),psiinv(q,q)
+      double precision sb(p),smu(q)
+      double precision tinv(q,q)      
 
 c+++++MCMC parameters
       integer mcmc(5),nburn,nskip,nsave,ndisplay
 
 c+++++Output
-      real*8 acrate(2)
-      real*8 cpo(nrec,2)
-      real*8 randsave(nsave,q*(nsubject+1))
-      real*8 thetasave(nsave,q+nfixed+q+(q*(q+1)/2)+2)
+      double precision acrate(2)
+      double precision cpo(nrec,2)
+      double precision randsave(nsave,q*(nsubject+1))
+      double precision thetasave(nsave,q+nfixed+q+(q*(q+1)/2)+2)
 
 c+++++Current values of the parameters
       integer ncluster,ss(nsubject)
-      real*8 alpha,beta(p),b(nsubject,q)
-      real*8 betar(q),bclus(nsubject,q)
-      real*8 mu(q),sigma(q,q),sigmainv(q,q)
+      double precision alpha,beta(p),b(nsubject,q)
+      double precision betar(q),bclus(nsubject,q)
+      double precision mu(q),sigma(q,q),sigmainv(q,q)
 
 c+++++Seeds
       integer seed(2),seed1,seed2
@@ -280,30 +280,30 @@ c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 c+++++fixed effects
       integer iflagp(p)
-      real*8 betac(p)
-      real*8 xtx(p,p),xty(p)
-      real*8 workmh1(p*(p+1)/2)
-      real*8 workp1(p,p),workp2(p,p)
-      real*8 workvp1(p)
+      double precision betac(p)
+      double precision xtx(p,p),xty(p)
+      double precision workmh1(p*(p+1)/2)
+      double precision workp1(p,p),workp2(p,p)
+      double precision workvp1(p)
 
 c+++++random effects
       integer iflagb(q)
-      real*8 quadf(q,q)
-      real*8 theta(q)
-      real*8 thetac(q)
-      real*8 zty(q),ztz(q,q)
-      real*8 workb1(q,q),workb2(q,q)
-      real*8 workmh2(q*(q+1)/2),workmh3(q*(q+1)/2)
-      real*8 workvb1(q),workvb2(q)
+      double precision quadf(q,q)
+      double precision theta(q)
+      double precision thetac(q)
+      double precision zty(q),ztz(q,q)
+      double precision workb1(q,q),workb2(q,q)
+      double precision workmh2(q*(q+1)/2),workmh3(q*(q+1)/2)
+      double precision workvb1(q),workvb2(q)
 
 c+++++DP
       integer ccluster(nsubject),cstrt(nsubject,nsubject)
-      real*8 newtheta(q,mpar)
-      real*8 prob(nsubject+mpar)
+      double precision newtheta(q,mpar)
+      double precision prob(nsubject+mpar)
 
 c++++ model's performance
-      real*8 mc(5)
-      real*8 betasave(p),bsave(nsubject,q)
+      double precision mc(5)
+      double precision betasave(p),bsave(nsubject,q)
 
 c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 c+++++Internal working space
@@ -315,30 +315,30 @@ c+++++General
       integer ihmssf,ni,ns
       integer ok,since,sprint 
       integer yij
-      real*8 acrate2
-      real*8 eta,mean,offset,ytilde
-      real*8 logcgkn,logcgko
-      real*8 loglikn,logliko
-      real*8 logpriorn,logprioro
-      real*8 ratio
-      real*8 tmp1,tmp2,tmp3
+      double precision acrate2
+      double precision eta,mean,offset,ytilde
+      double precision logcgkn,logcgko
+      double precision loglikn,logliko
+      double precision logpriorn,logprioro
+      double precision ratio
+      double precision tmp1,tmp2,tmp3
 
 c+++++MCMC
       integer dispcount,isave,iscan,nscan,skipcount 
 
 c+++++RNG and distributions
-      real*8 dpoiss,rnorm
+      double precision dpoiss,rnorm
       real runif
 
 c+++++DP
-      real*8 eps,rbeta,weight
+      double precision eps,rbeta,weight
       parameter(eps=0.01)
 
 c++++ model's performance
-      real*8 dbarc,dbar,dhat,pd,lpml
+      double precision dbarc,dbar,dhat,pd,lpml
 
 c+++++CPU time
-      real*8 sec00,sec0,sec1,sec
+      double precision sec00,sec0,sec1,sec
 
 c++++ parameters
       nburn=mcmc(1)
